package File::RsyBak::Unpacked;

our $DATE = '2015-10-21'; # DATE
our $DIST = 'File-RsyBak-Unpacked'; # DIST
our $VERSION = '0.28'; # VERSION

1;
# ABSTRACT: Backup files/directories with histories, using rsync (unpacked version)

__END__

=pod

=encoding UTF-8

=head1 NAME

File::RsyBak::Unpacked - Backup files/directories with histories, using rsync (unpacked version)

=head1 VERSION

This document describes version 0.28 of File::RsyBak::Unpacked (from Perl distribution File-RsyBak-Unpacked), released on 2015-10-21.

=head1 DESCRIPTION

This distribution is for testing/development purposes. Users should just install
the L<File::RsyBak> distribution because it has fewer dependencies.

=head1 SEE ALSO

L<File::RsyBak>

L<rsybak>

=head1 HOMEPAGE

Please visit the project's homepage at L<https://metacpan.org/release/File-RsyBak-Unpacked>.

=head1 SOURCE

Source repository is at L<https://github.com/perlancar/perl-File-RsyBak-Unpacked>.

=head1 BUGS

Please report any bugs or feature requests on the bugtracker website L<https://rt.cpan.org/Public/Dist/Display.html?Name=File-RsyBak-Unpacked>

When submitting a bug or request, please include a test-file or a
patch to an existing test-file that illustrates the bug or desired
feature.

=head1 AUTHOR

perlancar <perlancar@cpan.org>

=head1 COPYRIGHT AND LICENSE

This software is copyright (c) 2015 by perlancar@cpan.org.

This is free software; you can redistribute it and/or modify it under
the same terms as the Perl 5 programming language system itself.

=cut
